==> apache-artemis-2.33.0-source-release.tar.gz: apache-artemis-2.33.0/artemis-server/src/test/java/org/apache/activemq/artemis/spi/core/security/ActiveMQJAASSecurityManagerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.activemq.artemis.spi.core.security;

import javax.security.auth.Subject;
import java.security.Principal;

import org.apache.activemq.artemis.spi.core.security.jaas.RolePrincipal;
import org.apache.activemq.artemis.spi.core.security.jaas.UserPrincipal;
import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;

public class ActiveMQJAASSecurityManagerTest {

   final String user = "P";
   class UserFromOtherDomainPrincipal implements Principal {
      @Override
      public String getName() {
         return user;
      }
   }

   @Test
   public void getUserFromSubjectWithExternalPrinciple() throws Exception {

      ActiveMQJAASSecurityManager underTest = new ActiveMQJAASSecurityManager();
      assertEquals(UserPrincipal.class.getName(), underTest.getUserPrincipalClass());
      assertEquals(RolePrincipal.class.getName(), underTest.getRolePrincipalClass());

      Subject subject = new Subject();
      subject.getPrincipals().add(new ActiveMQJAASSecurityManagerTest.UserFromOtherDomainPrincipal());
      assertNull(underTest.getUserFromSubject(subject));

      underTest.setUserPrincipalClass(ActiveMQJAASSecurityManagerTest.UserFromOtherDomainPrincipal.class.getName());

      assertEquals(user, underTest.getUserFromSubject(subject));
   }

}

==> apache-artemis-2.42.0-source-release.tar.gz: apache-artemis-2.42.0/artemis-server/src/test/java/org/apache/activemq/artemis/spi/core/security/ActiveMQJAASSecurityManagerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.activemq.artemis.spi.core.security;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNull;

import javax.security.auth.Subject;
import java.security.Principal;

import org.apache.activemq.artemis.spi.core.security.jaas.RolePrincipal;
import org.apache.activemq.artemis.spi.core.security.jaas.UserPrincipal;
import org.junit.jupiter.api.Test;

public class ActiveMQJAASSecurityManagerTest {

   final String user = "P";
   class UserFromOtherDomainPrincipal implements Principal {
      @Override
      public String getName() {
         return user;
      }
   }

   @Test
   public void getUserFromSubjectWithExternalPrinciple() throws Exception {

      ActiveMQJAASSecurityManager underTest = new ActiveMQJAASSecurityManager();
      assertEquals(UserPrincipal.class.getName(), underTest.getUserPrincipalClass());
      assertEquals(RolePrincipal.class.getName(), underTest.getRolePrincipalClass());

      Subject subject = new Subject();
      subject.getPrincipals().add(new ActiveMQJAASSecurityManagerTest.UserFromOtherDomainPrincipal());
      assertNull(underTest.getUserFromSubject(subject));

      underTest.setUserPrincipalClass(ActiveMQJAASSecurityManagerTest.UserFromOtherDomainPrincipal.class.getName());

      assertEquals(user, underTest.getUserFromSubject(subject));
   }

}
